pg.ddx.io  pgsql-hackers@postgresql.org mailing list archive  
help / color / mirror / Atom feed
From: Tomas Vondra <tomas.vondra@2ndquadrant.com>
To: David Fetter <david@fetter.org>
Cc: Andrew Gierth <andrew@tao11.riddles.org.uk>
Cc: Kyotaro Horiguchi <horikyota.ntt@gmail.com>
Cc: pgsql-hackers@postgresql.org
Subject: Re: Efficient output for integer types
Date: Sat, 11 Jan 2020 14:31:59 +0100
Message-ID: <20200111133159.ppxnocexkdduo4m6@development> (raw)
In-Reply-To: <20190924052620.GP31596@fetter.org>
References: <20190920210916.GF31596@fetter.org>
	<20190920211813.GG31596@fetter.org>
	<87h856pekw.fsf@news-spur.riddles.org.uk>
	<20190921060835.GH31596@fetter.org>
	<87a7ayp4bm.fsf@news-spur.riddles.org.uk>
	<20190922215804.GL31596@fetter.org>
	<87pnjrns08.fsf@news-spur.riddles.org.uk>
	<20190923213506.GN31596@fetter.org>
	<20190924043018.GO31596@fetter.org>
	<20190924052620.GP31596@fetter.org>

Hi,

Any plans regarding committing this patch? I see the thread is silent
since September 24, when the last patch version was posted. The patch is
already marked as RFC since December, when David changed the status. I
don't have any opinion whether the patch is RFC or not (it might well
be), but IMHO it should have been mentioned in this thread.

I did a quick test to see how much more efficient this is, and for a
table with 10 bigint columns and 5M random rows the COPY to /dev/null
went from 3000 ms to ~2700 ms. That's not the 30% speedup mentioned by
David in the first message, but 10% is still pretty nice.

Of course, for real-world use cases the speedup will be lower because of
using other data types too, I/O etc. But it's still nice.

So, is anyone opposed to pushing this? If not, who'll to do that?  I see
Andrew Gierth was involved in the discussions on IRC and it's related to
the Ryu patch, so maybe he want's to take care of this. Andrew?


regards

-- 
Tomas Vondra                  http://www.2ndQuadrant.com
PostgreSQL Development, 24x7 Support, Remote DBA, Training & Services 





view thread (23+ messages)

Message-ID: <20200111133159.ppxnocexkdduo4m6@development>
Permalink:  ../20200111133159.ppxnocexkdduo4m6@development/
Also on:    postgresql.org/message-id/20200111133159.ppxnocexkdduo4m6@development

 · 

reply

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Reply to all the recipients using the --to and --cc options:
  reply via email

  To: pgsql-hackers@postgresql.org
  Cc: tomas.vondra@2ndquadrant.com, david@fetter.org, andrew@tao11.riddles.org.uk, horikyota.ntt@gmail.com
  Subject: Re: Efficient output for integer types
  In-Reply-To: <20200111133159.ppxnocexkdduo4m6@development>

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox